aboutsummaryrefslogtreecommitdiff
path: root/engine/lib/views.php
diff options
context:
space:
mode:
authorewinslow <ewinslow@36083f99-b078-4883-b0ff-0f9b5a30f544>2011-02-18 18:03:24 +0000
committerewinslow <ewinslow@36083f99-b078-4883-b0ff-0f9b5a30f544>2011-02-18 18:03:24 +0000
commit562bc001f3002f43c343cc63bbbe3e9cb421de32 (patch)
tree232e0534386a6250315f20a8eaf9037197b8003d /engine/lib/views.php
parent412d337ee7f1463dc4ea4cf1d23415b10749f996 (diff)
downloadelgg-562bc001f3002f43c343cc63bbbe3e9cb421de32.tar.gz
elgg-562bc001f3002f43c343cc63bbbe3e9cb421de32.tar.bz2
Refs #2950: layout/shells => page/layouts
git-svn-id: http://code.elgg.org/elgg/trunk@8286 36083f99-b078-4883-b0ff-0f9b5a30f544
Diffstat (limited to 'engine/lib/views.php')
-rw-r--r--engine/lib/views.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/engine/lib/views.php b/engine/lib/views.php
index 6783cfcc5..5ea93de7c 100644
--- a/engine/lib/views.php
+++ b/engine/lib/views.php
@@ -621,7 +621,7 @@ function elgg_view_page($title, $body, $page_shell = 'default', $vars = array())
* - two_sidebar A content column with two sidebars.
* - widgets A widget canvas.
*
* The layout views take the form layout/shells/$layout_name
* See the individual layouts for what options are supported. The three most
* common layouts have these parameters:
* one_column
@@ -637,7 +637,7 @@ function elgg_view_page($title, $body, $page_shell = 'default', $vars = array())
* filter_context => string (selected content filter)
* See the content layout view for more parameters
*
* @param string $layout The name of the view in layout/shells/.
* @param array $vars Associative array of parameters for the layout view
*
* @return string The layout
@@ -656,10 +656,10 @@ function elgg_view_layout($layout_name, $vars = array()) {
$param_array = $vars;
}
- if (elgg_view_exists("layout/shells/$layout_name")) {
- return elgg_view("layout/shells/$layout_name", $param_array);
+ if (elgg_view_exists("page/layouts/$layout_name")) {
+ return elgg_view("page/layouts/$layout_name", $param_array);
} else {
- return elgg_view("layout/shells/default", $param_array);
+ return elgg_view("page/layouts/default", $param_array);
}
}
@@ -621,7 +621,7 @@ function elgg_view_page($title, $body, $page_shell = 'default', $vars = array())
* - widgets A widget canvas.
*
- * The layout views take the form layout/shells/$layout_name
+ * The layout views take the form page/layouts/$layout_name
* See the individual layouts for what options are supported. The three most
* common layouts have these parameters:
@@ -637,7 +637,7 @@ function elgg_view_page($title, $body, $page_shell = 'default', $vars = array())
* See the content layout view for more parameters
*
- * @param string $layout The name of the view in layout/shells/.
+ * @param string $layout The name of the view in page/layouts/.
* @param array $vars Associative array of parameters for the layout view
*